@@ -33,28 +33,38 @@ use Storable qw( retrieve );
 use File::Spec::Functions qw(
   catdir catfile catpath tmpdir splitpath rel2abs curdir
 );
-use Module::CoreList 2.18 qw();
+use Module::CoreList 2.27 qw();
 
 require Perl::Dist::WiX::Asset::Perl;
 require Perl::Dist::WiX::Toolchain;
 require File::List::Object;
 
-our $VERSION = '1.102_101';
+our $VERSION = '1.102_102';
 $VERSION =~ s/_//sm;
 
+# The commented lines are needed for 5.12, but may break 5.8.
+# Will check.
+
 Readonly my %CORE_MODULE_FIX => (
-	'IO::Compress'        => 'IO::Compress::Base',
-	'Filter'              => 'Filter::Util::Call',
-	'autodie'             => 'Fatal',
-	'Pod'                 => 'Pod::Man',
-	'Text'                => 'Text::Tabs',
-	'PathTools'           => 'Cwd',
-	'Scalar::List::Utils' => 'List::Util',
+	'IO::Compress' => 'IO::Compress::Base',
+	'Filter'       => 'Filter::Util::Call',
+
+#	'autodie'              => 'Fatal',
+	'Pod'                  => 'Pod::Man',
+	'Text'                 => 'Text::Tabs',
+	'PathTools'            => 'Cwd',
+	'Scalar::List::Utils'  => 'List::Util',
+	'Locale::Constants'    => 'Locale::Codes',
+	'TermReadKey'          => 'Term::ReadKey',
+	'Term::ReadLine::Perl' => 'Term::ReadLine',
+	'libwww::perl'         => 'LWP',
+	'LWP::UserAgent'       => 'LWP',
 );
 
 Readonly my %DIST_TO_MODULE_FIX => (
-	'CGI.pm'               => 'CGI',
-	'Fatal'                => 'autodie',
+	'CGI.pm' => 'CGI',
+
+#	'Fatal'                => 'autodie',
 	'Locale::Maketext'     => 'Locale-Maketext',
 	'Pod::Man'             => 'Pod',
 	'Text::Tabs'           => 'Text',
@@ -421,6 +431,13 @@ sub _install_cpan_module {
 	  ? 1
 	  : 0;
 
+	# Override core determination for this module.
+	# (It's not in core, but other modules that this distribution
+	# installs are)
+	if ('Locale::Codes' eq $module_id) {
+		$core = 1;
+	}
+
 	# Actually do the installation.
 	$self->install_distribution(
 		name     => $module_file,
@@ -453,10 +470,6 @@ sub _skip_upgrade {
 	# If the ID is CGI::Carp, there's a bug in the index.
 	return 1 if $module->id() eq 'CGI::Carp';
 
-	# DON'T try to install ExtUtils::CBuilder, we
-	# already upgraded it as far as we can. RT#54728.
-	return 1 if $module->cpan_file() =~ m{/ExtUtils-CBuilder-0 [.] 2701}msx;
-
 	# If the ID is ExtUtils::MakeMaker, we've already installed it.
 	# There were some files gotten rid of after 6.50, so
 	# install_cpan_upgrades thinks that it needs to upgrade
@@ -468,14 +481,6 @@ sub _skip_upgrade {
 	# Skip B::C, it does not install on 5.8.9.
 	return 1 if $module->cpan_file() =~ m{/B-C-1 [.]}msx;
 
-	# Skip autodie 2.08 and 2.09, waiting on RT#54525.
-	if (( $module->cpan_file() =~ m{/autodie-2 [.] 0 [89]}msx )
-		and (  ( $self->perl_version() eq '5101' )
-			or ( $self->perl_version() eq 'git' ) ) )
-	{
-		return 1;
-	}
-
 	return 0;
 } ## end sub _skip_upgrade
 
@@ -519,7 +524,7 @@ sub install_perl {
 
 
 
-=head2 install_perl_* (* = git, 589, 5100, or 5101)
+=head2 install_perl_* (* = git, 589, 5100, 5101, 5115, or 5120)
 
 	$self->install_perl_5100;
 
@@ -649,8 +654,8 @@ sub install_perl_bin {
 	$self->_make_path( catdir( $self->image_dir(), qw(perl site bin) ) );
 
 	# Add to the environment variables
-	$self->add_path( 'perl', 'bin' );
 	$self->add_path( 'perl', 'site', 'bin' );
+	$self->add_path( 'perl', 'bin' );
 
 	return 1;
 } ## end sub install_perl_bin
@@ -823,6 +828,62 @@ sub install_perl_5115 {
 
 
 
+sub install_perl_5120 {
+	my $self = shift;
+
+	# Prefetch and predelegate the toolchain so that it
+	# fails early if there's a problem
+	$self->trace_line( 1, "Pregenerating toolchain...\n" );
+	my $toolchain = Perl::Dist::WiX::Toolchain->new(
+		perl_version => $self->perl_version_literal,
+		cpan         => $self->cpan->as_string,
+		bits         => $self->bits(),
+	) or PDWiX->throw('Failed to resolve toolchain modules');
+	unless ( eval { $toolchain->delegate; 1; } ) {
+		PDWiX::Caught->throw(
+			message => 'Delegation error occured',
+			info    => defined($EVAL_ERROR) ? $EVAL_ERROR : 'Unknown error',
+		);
+	}
+	if ( defined $toolchain->get_error() ) {
+		PDWiX::Caught->throw(
+			message => 'Failed to generate toolchain distributions',
+			info    => $toolchain->get_error() );
+	}
+	$self->_set_toolchain($toolchain);
+
+	# Make the perl directory if it hasn't been made already.
+	$self->_make_path( $self->_dir('perl') );
+
+	# Install the main binary
+	$self->install_perl_bin(
+		name => 'perl',
+		url =>
+'http://search.cpan.org/CPAN/authors/id/J/JE/JESSE/perl-5.12.0-RC0.tar.gz',
+		unpack_to  => 'perl',
+		install_to => 'perl',
+		toolchain  => $toolchain,
+		patch      => [ qw{
+			  lib/CPAN/Config.pm
+			  win32/config.gc
+			  win32/config.gc64nox
+			  win32/config_sh.PL
+			  win32/config_H.gc
+			  win32/config_H.gc64nox
+			  }
+		],
+		license => {
+			'perl-5.12.0-RC0/Readme'   => 'perl/Readme',
+			'perl-5.12.0-RC0/Artistic' => 'perl/Artistic',
+			'perl-5.12.0-RC0/Copying'  => 'perl/Copying',
+		},
+	);
+
+	return 1;
+} ## end sub install_perl_5120
+
+
+
 sub install_perl_git {
 	my $self = shift;
 
@@ -940,11 +1001,6 @@ sub install_perl_toolchain {
 			# Upgrading to this version, instead...
 			$dist = 'STSI/TermReadKey-2.30.01.tar.gz';
 		}
-		if ( $dist =~ /Test-Harness-3 [.] 20/msx ) {
-
-			# 3.20 has a test bug... waiting for RT#54028
-			$force = 1;
-		}
 		if ( $dist =~ /CPAN-1 [.] 9402/msx ) {
 
 			# 1.9402 fails its tests... ANDK says it's a test bug.
@@ -953,16 +1009,6 @@ sub install_perl_toolchain {
 			$dist  = 'ANDK/CPAN-1.94_56.tar.gz';
 			$force = 1;
 		}
-		if ( $dist =~ /ExtUtils-ParseXS-2[.]20(?:02)?[.]tar[.]gz/msx ) {
-
-			# 2.20 and 2.2002 are buggy on 5.8.9.
-			$dist = 'DAGOLDEN/ExtUtils-ParseXS-2.20_05.tar.gz';
-		}
-		if ( $dist =~ /ExtUtils-CBuilder-0[.]2701[.]tar[.]gz/msx ) {
-
-			# 0.2701 does not pass tests on 5.10.1. RT#54728.
-			$dist = 'DAGOLDEN/ExtUtils-CBuilder-0.27.tar.gz';
-		}
 		if ( $dist =~ /Win32API-Registry-0 [.] 31/msx ) {
 
 			# 0.31 does not include a Makefile.PL.
