@@ -8,12 +8,12 @@ use Moose::Util::TypeConstraints;
 use English qw( -no_match_vars );
 use Carp qw();
 use Params::Util qw( _HASH _ARRAY );
-use Module::CoreList 2.18 qw();
+use Module::CoreList 2.27 qw();
 use IO::Capture::Stdout qw();
 use IO::Capture::Stderr qw();
 use vars qw(@DELEGATE);
 
-our $VERSION = '1.102_101';
+our $VERSION = '1.102_102';
 $VERSION =~ s/_//ms;
 
 extends qw(
@@ -198,13 +198,15 @@ sub _modules_build {
 	  URI
 	  HTML::Tagset
 	  HTML::Parser
-	  LWP::UserAgent};
+	  LWP::UserAgent
+	};
 
 	my %modules = ( '5.008009' => \@modules_list, );
 	$modules{'5.010000'} = $modules{'5.008009'};
 	$modules{'5.010001'} = $modules{'5.008009'};
 	$modules{'5.011001'} = $modules{'5.008009'};
 	$modules{'5.011005'} = $modules{'5.008009'};
+	$modules{'5.012000'} = $modules{'5.008009'};
 
 	return \%modules;
 } ## end sub _modules_build
@@ -217,6 +219,7 @@ sub _corelist_version_build {
 		'5.010001' => '5.010001',
 		'5.011001' => '5.011001',
 		'5.011005' => '5.011005',
+		'5.012000' => '5.012000',
 	);
 
 	return \%corelist;
